@@ -39,7 +39,7 @@ pyramid.plot<-function(lx,rx,labels=NA,top.labels=c("Male","Age","Female"),
    else axis(2,at=1:ncats * as.logical(rx+1),labels=rep("",ncats),pos=gap,
     tcl=-0.25)
    if(!is.null(lxdim)) axis(4,at=1:ncats,labels=rep("",ncats),pos=-gap,tcl=-0.25)
-   else axis(4,at=1:ncats * as.logical(lx+1),labels=rep("",ncats),pos=gap,
+   else axis(4,at=1:ncats * as.logical(lx+1),labels=rep("",ncats),pos=-gap,
     tcl=-0.25)
   }
   # display the category labels
@@ -76,8 +76,12 @@ pyramid.plot<-function(lx,rx,labels=NA,top.labels=c("Male","Age","Female"),
    col=rxcol)
   if(show.values) {
    par(xpd=TRUE)
-   text(-(gap+lx),1:ncats,round(lx,ndig),pos=2,cex=labelcex)
-   text(gap+rx,1:ncats,round(rx,ndig),pos=4,cex=labelcex)
+   #text(-(gap+lx),1:ncats,round(lx,ndig),pos=2,cex=labelcex)
+   #text(gap+rx,1:ncats,round(rx,ndig),pos=4,cex=labelcex)
+   lxt<-formatC(lx,format="f",digits=ndig)
+   rxt<-formatC(rx,format="f",digits=ndig)
+   text(-(gap+lx),1:ncats,lxt,pos=2,cex=labelcex)
+   text(gap+rx,1:ncats,rxt,pos=4,cex=labelcex)
    par(xpd=FALSE)
   }
  }
